import { getPosts } from '$lib/server/db';
import { json } from '@sveltejs/kit';
import { Logger } from '$lib/log';

import type { RequestHandler } from './$types';
import { performance } from 'perf_hooks';

const logger = new Logger('+server.ts API');

export const GET = (async ({ url, setHeaders }) => {
  setHeaders({
    'cache-control': 'max-age=10'
  });
  const start = performance.now();
  const since = url.searchParams.get('since');
  const before = url.searchParams.get('before');
  let count = Number.parseInt(url.searchParams.get('count') || '');
  if (isNaN(count)) {
    count = 10;
  }
  count = Math.min(count, 100);
  const afterCount = performance.now();
  logger.debug('Count took', afterCount - start, 'ms');
  const posts = await getPosts(since, before, count);
  const afterFetch = performance.now();
  logger.debug('DB took', afterFetch - afterCount, 'ms');
  const resp = json(posts);
  const afterResponse = performance.now();
  logger.debug('Response took', afterResponse - afterFetch, 'ms');
  return resp;
}) satisfies RequestHandler;
